@@ -19,6 +19,17 @@ class PlaylistItems:
     def __init__(self, playlist_id, api_key=API_KEY):
         self.playlist_id = playlist_id
         self.api_key = api_key
+
+    def _try_parse(self, item, key):
+        try:
+            parsed = item[key]
+        except KeyError:
+            logging.warn(
+                f"YouTube Data API v3 does not provide the `{key}` parameter fo"
+                f"r the requested playlist item. Setting it as `None`"
+            )
+            parsed = None
+        return parsed
     
     def _parse_response(self, data):
         """Parses the API 'PlaylistItems: list' endpoint's JSON
@@ -39,10 +50,10 @@ class PlaylistItems:
         parsed = []
         for item in items:
             parsed.append({
-                'id': item['contentDetails']['videoId'],
-                'title': item['snippet']['title'],
-                'description': item['snippet']['description'],
-                'published_at': item['snippet']['publishedAt']
+                'id': self._try_parse(item['contentDetails'], 'videoId'),
+                'title': self._try_parse(item['snippet'], 'title'),
+                'description': self._try_parse(item['snippet'], 'description'),
+                'published_at': self._try_parse(item['snippet'], 'publishedAt')
             })
             logging.info(f"Got PlaylistItem -> id: {item['id']} / title: {item['snippet']['title']}")
         try:
